summaryrefslogtreecommitdiffstats
path: root/kio/kio/ksambashare.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/ksambashare.cpp')
-rw-r--r--kio/kio/ksambashare.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kio/kio/ksambashare.cpp b/kio/kio/ksambashare.cpp
index 7fba51ae2..defeae4a7 100644
--- a/kio/kio/ksambashare.cpp
+++ b/kio/kio/ksambashare.cpp
@@ -33,7 +33,7 @@ public:
KSambaSharePrivate();
bool readSmbConf();
- bool tqfindSmbConf();
+ bool findSmbConf();
bool load();
TQDict<bool> sharedPaths;
@@ -49,20 +49,20 @@ KSambaSharePrivate::KSambaSharePrivate()
#define FILESHARECONF "/etc/security/fileshare.conf"
bool KSambaSharePrivate::load() {
- if (!tqfindSmbConf())
+ if (!findSmbConf())
return false;
return readSmbConf();
}
/**
* Try to tqfind the samba config file path
* First tries the kconfig, then checks
* several well-known paths
* @return wether a smb.conf was found.
**/
-bool KSambaSharePrivate::tqfindSmbConf() {
- KSimpleConfig config(TQString::tqfromLatin1(FILESHARECONF),true);
+bool KSambaSharePrivate::findSmbConf() {
+ KSimpleConfig config(TQString::fromLatin1(FILESHARECONF),true);
smbConf = config.readEntry("SMBCONF");
if ( TQFile::exists(smbConf) )
@@ -144,7 +144,7 @@ bool KSambaSharePrivate::readSmbConf() {
}
// parameter
- int i = completeLine.tqfind('=');
+ int i = completeLine.find('=');
if (i>-1)
{
@@ -203,7 +203,7 @@ bool KSambaShare::isDirectoryShared( const TQString & path ) const {
if ( path[path.length()-1] != '/' )
fixedPath += '/';
- return d->sharedPaths.tqfind(fixedPath) != 0;
+ return d->sharedPaths.find(fixedPath) != 0;
}
TQStringList KSambaShare::sharedDirectories() const {
@@ -49,20 +49,20 @@ KSambaSharePrivate::KSambaSharePrivate()
}
/**
- * Try to tqfind the samba config file path
+ * Try to find the samba config file path
* First tries the kconfig, then checks
* several well-known paths